@@ -30,7 +30,7 @@ char* cperfdmf_getExtendedError() {
 }
 
 
-// this is here because strdup is not actually part of the C(99) library
+/* this is here because strdup is not actually part of the C(99) library */
 static char* strduplicate (char *source) {
   char* retStr = (char*) malloc (sizeof(char) * (strlen(source) + 1));
   if (!retStr)
@@ -39,19 +39,22 @@ static char* strduplicate (char *source) {
   return retStr;
 }
 
-
-// Possible return values 
-// CPERFDMF_ERR_INTERNAL_ERROR
-// CPERFDMF_ERR_OK
+/*
+ Possible return values 
+ CPERFDMF_ERR_INTERNAL_ERROR
+ CPERFDMF_ERR_OK
+*/
 int getNextString(char** location, char* buffer, char* str, int* position) {
-  int pos = *position;  // copy in the current position in 'str'
+  int pos = *position;  /* copy in the current position in 'str' */
   int bufpos = 0;
   int done = 0;
   while (pos < strlen(str) && !done) {
 
     if (str[pos] == '\\') {  
-      // skip over escape sequences (i.e. skip the \ and copy the 
-      // next character, even if it is a semi-colon
+      /*
+	skip over escape sequences (i.e. skip the \ and copy the 
+	next character, even if it is a semi-colon
+      */
       pos++;
       if (str[pos]) {
 	buffer[bufpos++] = str[pos++];
@@ -66,27 +69,26 @@ int getNextString(char** location, char* buffer, char* str, int* position) {
   }
 
   if (!done) {
-    // we reached the end of the string before finding a (non-escaped)
-    // semi-colon, this is bad.
+    /* we reached the end of the string before finding a (non-escaped)
+       semi-colon, this is bad. */
     cperfdmf_setExtendedError("%s(%d): Bad Parse, couldn't find a semi-colon\n", __FILE__, __LINE__);
     return CPERFDMF_ERR_INTERNAL_ERROR;
   }
 
-  buffer[bufpos] = 0;  // null terminate
+  buffer[bufpos] = 0;  /* null terminate */
 
-  // set the values to be returned
-  *position = ++pos;  // skip over the semi-colon
-  *location = strduplicate(buffer);  // copy out the string
-  //  printf ("new ptr = 0x%x\n",*location);
+  /* set the values to be returned */
+  *position = ++pos;  /* skip over the semi-colon */
+  *location = strduplicate(buffer);  /* copy out the string */
   return CPERFDMF_OK;
 }
 
 
-// return values
-// CPERFDMF_OK
-// CPERFDMF_INTERNAL_ERROR
+/* return values
+   CPERFDMF_OK
+   CPERFDMF_INTERNAL_ERROR */
 int parseStringList(char*** target, int* count, char* list) {
-  if (list == NULL) {  // no items
+  if (list == NULL) {  /* no items */
     *target = NULL;
     *count = 0;
     return CPERFDMF_OK;
@@ -96,10 +98,10 @@ int parseStringList(char*** target, int* count, char* list) {
   int len = strlen(list);
   int numItems = 0;
 
-  // first count the delimiters to see how many items there are
+  /* first count the delimiters to see how many items there are */
   while (pos < len) {
     if (list[pos] == '\\') {
-      pos+=2;  // skip over the \ and the next char
+      pos+=2;  /* skip over the \ and the next char */
     } else {
       if (list[pos] == ';') {
 	numItems++;
@@ -108,7 +110,7 @@ int parseStringList(char*** target, int* count, char* list) {
     }
   }
 
-  if (numItems == 0) {  // nothing in the list
+  if (numItems == 0) {  /* nothing in the list */
     *target = NULL;
     *count = 0;
     return CPERFDMF_OK;
@@ -158,7 +160,7 @@ int parseIntegerList(int** target, int* count, char* list) {
   len = strlen(list);
   numItems = 0;
 
-  // first count the delimiters to see how many we've got
+  /* first count the delimiters to see how many we've got */
   while (pos < len) {
     if (list[pos] == ';') {
       numItems++;
@@ -166,7 +168,7 @@ int parseIntegerList(int** target, int* count, char* list) {
     pos++;
   }
 
-  if (numItems == 0) {  // nothing in the list
+  if (numItems == 0) {  /* nothing in the list */
     *target = NULL;
     *count = 0;
     return CPERFDMF_OK;
@@ -189,7 +191,7 @@ int parseIntegerList(int** target, int* count, char* list) {
       pos++;
     }
 
-    // we are either at the end (pos == len) or at a delimiter
+    /* we are either at the end (pos == len) or at a delimiter */
 
     length = pos - start;
 
@@ -200,13 +202,13 @@ int parseIntegerList(int** target, int* count, char* list) {
     }
 
     strncpy (tmpstr,&list[start],pos-start);
-    tmpstr[length] = 0; // null terminate
+    tmpstr[length] = 0; /* null terminate */
 
     itemList[itemIdx] = atoi(tmpstr);
     free (tmpstr);
     itemIdx++;
     
-    pos++; // skip over the delimiter
+    pos++; /* skip over the delimiter */
     start = pos;
 
   }
@@ -220,7 +222,7 @@ int parseIntegerList(int** target, int* count, char* list) {
 
 
 void writeNextString(char* buffer, int* position, char* str) {
-  int pos = *position;  // copy in the current position
+  int pos = *position;  /* copy in the current position*/
 
   if (str) {
     while (*str) {
@@ -235,7 +237,7 @@ void writeNextString(char* buffer, int* position, char* str) {
 
   buffer[pos++] = ';';
 
-  // write back new position
+  /* write back new position*/
   *position = pos;
 }
 
@@ -248,33 +250,33 @@ void writeNextInteger(char* buffer, int* position, int integer) {
 
 
 
-// Possible return values 
-// CPERFDMF_ERR_INTERNAL_ERROR
-// CPERFDMF_ERR_OK
+/* Possible return values */
+/* CPERFDMF_ERR_INTERNAL_ERROR*/
+/* CPERFDMF_ERR_OK*/
 int getNextInteger(int* location, char* buffer, char* str, int* position) {
   char *tmpStr = NULL;
-  // simply call getNextString and convert the output
+  /* simply call getNextString and convert the output*/
   int retval = getNextString(&tmpStr, buffer, str, position);
   if (retval != CPERFDMF_OK)
     return retval;
 
-  *location = atoi(tmpStr);  // copy out the integer
+  *location = atoi(tmpStr);  /* copy out the integer*/
   free(tmpStr);
   return CPERFDMF_OK;
 }
 
-// Possible return values 
-// CPERFDMF_ERR_INTERNAL_ERROR
-// CPERFDMF_ERR_OK
+/* Possible return values */
+/* CPERFDMF_ERR_INTERNAL_ERROR*/
+/* CPERFDMF_ERR_OK*/
 int getNextDouble(double *location, char *buffer, char *str, int *position) {
   char *tmpStr = NULL;
-  // simply call getNextString and convert the output
+  /* simply call getNextString and convert the output*/
   int retval = getNextString(&tmpStr, buffer, str, position);
   if (retval != CPERFDMF_OK)
     return retval;
 
-  *location = atof(tmpStr);  // copy out the double
-  // printf ("double(%s) = %.20g\n",tmpStr,*location);
+  *location = atof(tmpStr);  /* copy out the double*/
+  /* printf ("double(%s) = %.20g\n",tmpStr,*location);*/
   free(tmpStr);
   return CPERFDMF_OK;
 }
@@ -290,15 +292,15 @@ static int getApplicationDetail(cperfdmf_application_t* app, int appId, char** f
     return ec;
   
   
-  // parse the string into the 'cperfdmf_application_t' type
+  /* parse the string into the 'cperfdmf_application_t' type*/
   char *buffer = (char *) malloc (sizeof(char) * strlen(appDetail));
   if (!buffer) {
     cperfdmf_setExtendedError("%s(%d): malloc failed\n", __FILE__, __LINE__);
     return CPERFDMF_ERR_INTERNAL_ERROR;
   }
 
-  // assign the fieldNames (note: every application has the same pointer since we only need to keep
-  // one copy of the fieldNames
+  /* assign the fieldNames (note: every application has the same pointer since we only need to keep*/
+  /* one copy of the fieldNames*/
   app->numFields = numFields;
   app->fieldNames = fieldNames;
 
@@ -320,10 +322,9 @@ static int getApplicationDetail(cperfdmf_application_t* app, int appId, char** f
   return CPERFDMF_OK;
 }
 
-//////////////////////////////////////////////////////////////////////////
-// API Functions
-//////////////////////////////////////////////////////////////////////////
-
+/*
+  API Functions
+*/
 
 
 int strlenHelper(char *str) {
@@ -335,7 +336,7 @@ int strlenHelper(char *str) {
 int cperfdmf_saveApplication(cperfdmf_application_t* app) {
   char* appDetail = NULL;
   int pos, ec, i;
-  int stringSize = 2*strlenHelper(app->name) + 100; // name + id
+  int stringSize = 2*strlenHelper(app->name) + 100; /* name + id*/
 
   for (i = 0; i < app->numFields; i++) {
     stringSize += 2*strlenHelper(app->fields[i]);
@@ -355,12 +356,11 @@ int cperfdmf_saveApplication(cperfdmf_application_t* app) {
     writeNextString(appDetail, &pos, app->fields[i]);
   }
   
-  appDetail[pos] = 0;  // null terminate
+  appDetail[pos] = 0;  /* null terminate */
   int newId;
 
   ec = jcperfdmf_setApplicationDetail(appDetail, &newId);
 
-  //printf ("new App id = %d\n", newId);
   app->appId = newId;
 
   free (appDetail);
@@ -373,7 +373,7 @@ int cperfdmf_saveExperiment(cperfdmf_experiment_t* exp) {
   char* expDetail = NULL;
   int pos, ec, i;
 
-  int stringSize = 2*strlenHelper(exp->name) + 200; // name + appID + expID
+  int stringSize = 2*strlenHelper(exp->name) + 200; /* name + appID + expID */
 
   for (i = 0; i < exp->numFields; i++) {
     stringSize += 2*strlenHelper(exp->fields[i]);
@@ -396,7 +396,7 @@ int cperfdmf_saveExperiment(cperfdmf_experiment_t* exp) {
     writeNextString(expDetail, &pos, exp->fields[i]);
   }
 
-  expDetail[pos] = 0;  // null terminate
+  expDetail[pos] = 0;  /* null terminate*/
   int newId;
   ec = jcperfdmf_setExperimentDetail(expDetail, &newId);
 
@@ -412,7 +412,7 @@ int cperfdmf_saveTrial(cperfdmf_trial_t* trial) {
   char* trialDetail = NULL;
   int pos, ec, i;
 
-  int stringSize = 2*strlenHelper(trial->name) + 300; // name + appID + expID + trialID
+  int stringSize = 2*strlenHelper(trial->name) + 300; /* name + appID + expID + trialID*/
 
   for (i = 0; i < trial->numFields; i++) {
     stringSize += 2*strlenHelper(trial->fields[i]);
@@ -436,7 +436,7 @@ int cperfdmf_saveTrial(cperfdmf_trial_t* trial) {
   }
 
 
-  trialDetail[pos] = 0;  // null terminate
+  trialDetail[pos] = 0;  /* null terminate*/
   int newId;
   ec = jcperfdmf_setTrialDetail(trialDetail, &newId);
 
@@ -450,7 +450,7 @@ int cperfdmf_saveTrial(cperfdmf_trial_t* trial) {
 
 
 int cperfdmf_initialize(char *configFile) {
-  // hold on to it
+  /* hold on to it*/
   theConfigFile = strduplicate(configFile);
   return jcperfdmf_init(theConfigFile);
 }
@@ -488,7 +488,7 @@ void cperfdmf_freeApplicationList(cperfdmf_application_t* applications, int numA
   int i, j;
   for (i=0; i<numApplications; i++) {
 
-    if (i==0) { // only free the field names once
+    if (i==0) { /* only free the field names once*/
       free (applications[i].fieldNames);
     }
     free (applications[i].name);
@@ -553,7 +553,7 @@ int cperfdmf_getApplications(cperfdmf_application_t** applications, int* numAppl
     return ec;
   }
 
-  // now get the metadata
+  /* now get the metadata*/
   char* metaDataStr = NULL;
   if (CPERFDMF_OK != (ec = jcperfdmf_getApplicationMetaData(&metaDataStr))) {
     return ec;
@@ -602,7 +602,7 @@ int cperfdmf_getExperiments(cperfdmf_experiment_t** experiments, int* numExperim
   }
 
 
-  // now get the metadata
+  /* now get the metadata*/
   char* metaDataStr = NULL;
   if (CPERFDMF_OK != (ec = jcperfdmf_getExperimentMetaData(&metaDataStr))) {
     return ec;
@@ -629,7 +629,7 @@ int cperfdmf_getExperiments(cperfdmf_experiment_t** experiments, int* numExperim
       return ec;
     }
    
-    // parse the string into the 'cperfdmf_experiment_t' type
+    /* parse the string into the 'cperfdmf_experiment_t' type*/
     char *buffer = (char *) malloc (sizeof(char) * strlen(expDetail));
     if (!buffer) {
       cperfdmf_setExtendedError("%s(%d): malloc failed\n", __FILE__, __LINE__);
@@ -637,8 +637,8 @@ int cperfdmf_getExperiments(cperfdmf_experiment_t** experiments, int* numExperim
     }
 
 
-    // assign the fieldNames (note: every application has the same pointer since we only need to keep
-    // one copy of the fieldNames
+    /* assign the fieldNames (note: every application has the same pointer since we only need to keep*/
+    /* one copy of the fieldNames*/
     exps[i].numFields = numFields;
     exps[i].fieldNames = fieldNames;
     
@@ -685,7 +685,7 @@ int cperfdmf_getTrials(cperfdmf_trial_t** trials, int* numTrials, int expId) {
 
 
 
-  // now get the metadata
+  /* now get the metadata*/
   char* metaDataStr = NULL;
   if (CPERFDMF_OK != (ec = jcperfdmf_getTrialMetaData(&metaDataStr))) {
     return ec;
@@ -716,9 +716,9 @@ int cperfdmf_getTrials(cperfdmf_trial_t** trials, int* numTrials, int expId) {
       return ec;
     }
 
-    //printf ("got back trial detail '%s'\n",trialDetail);
+    /*printf ("got back trial detail '%s'\n",trialDetail);*/
   
-    // parse the string into the 'trial' type
+    /* parse the string into the 'trial' type*/
     char *buffer = (char *) malloc (sizeof(char) * strlen(trialDetail));
     if (!buffer) {
       cperfdmf_setExtendedError("%s(%d): malloc failed\n", __FILE__, __LINE__);
@@ -726,8 +726,8 @@ int cperfdmf_getTrials(cperfdmf_trial_t** trials, int* numTrials, int expId) {
     }
 
 
-    // assign the fieldNames (note: every application has the same pointer since we only need to keep
-    // one copy of the fieldNames
+    /* assign the fieldNames (note: every application has the same pointer since we only need to keep*/
+    /* one copy of the fieldNames*/
     trls[i].numFields = numFields;
     trls[i].fieldNames = fieldNames;
 
@@ -774,7 +774,7 @@ int cperfdmf_getMetrics(char*** metrics, int* numMetrics) {
     return ec;
   }
 
-  // careful, parseStringList modifies metrics and numMetrics
+  /* careful, parseStringList modifies metrics and numMetrics*/
   return parseStringList(metrics, numMetrics, metricStr); 
 }
 
@@ -788,7 +788,7 @@ int cperfdmf_getFunctions(char*** functions, int* numFunctions) {
     return ec;
   }
 
-  // careful, parseStringList modifies functions and numFunctions
+  /* careful, parseStringList modifies functions and numFunctions*/
   return parseStringList(functions, numFunctions, functionStr);
 }
 
@@ -801,7 +801,7 @@ int cperfdmf_getGroups(char*** groups, int* numGroups) {
     return ec;
   }
 
-  //printf ("got groups: %s\n", groupStr);
+  /*printf ("got groups: %s\n", groupStr);*/
   ec = parseStringList(groups, numGroups, groupStr);
   free (groupStr);
   return ec;
@@ -825,9 +825,9 @@ int cperfdmf_getValues(cperfdmf_profile_t* prof, int functionId, int metric, int
     return CPERFDMF_NON_EXISTENT;
   }
 
-  //  printf ("got back profile str: %s\n", profileStr);
+  /*  printf ("got back profile str: %s\n", profileStr);*/
 
-  // parse the string into the 'profile' type
+  /* parse the string into the 'profile' type*/
   buffer = (char*) malloc (sizeof(char) * strlen(profileStr));
   if (!buffer) {
     cperfdmf_setExtendedError("%s(%d): malloc failed\n", __FILE__, __LINE__);
@@ -845,8 +845,8 @@ int cperfdmf_getValues(cperfdmf_profile_t* prof, int functionId, int metric, int
   getNextInteger(&prof->numSubroutines, buffer, profileStr, &pos);
   getNextString(&groupStr, buffer, profileStr, &pos);
   
-  // replace '@' with ';' in the group list, now we can use our
-  // regular parse function to get the list of groups;
+  /* replace '@' with ';' in the group list, now we can use our*/
+  /* regular parse function to get the list of groups;*/
   for (i=0; i<strlen(groupStr); i++) {
     if (groupStr[i] == '@') {
       groupStr[i] = ';';
@@ -888,7 +888,7 @@ int cperfdmf_getUserEvents(cperfdmf_userEvent_t **userEvents, int *numUserEvents
     return ec;
   }
 
-  //printf ("userEventStr = %s\n",userEventStr);
+  /*printf ("userEventStr = %s\n",userEventStr);*/
 
   if (userEventStr == NULL) {
     return CPERFDMF_NON_EXISTENT;
@@ -902,7 +902,7 @@ int cperfdmf_getUserEvents(cperfdmf_userEvent_t **userEvents, int *numUserEvents
 
   int pos = 0;
 
-  // the first element in the string is the number of events to follow
+  /* the first element in the string is the number of events to follow*/
   int numEvents;
   if (CPERFDMF_OK != (ec = getNextInteger(&numEvents, buffer, userEventStr, &pos))) {
     return ec;
@@ -915,7 +915,7 @@ int cperfdmf_getUserEvents(cperfdmf_userEvent_t **userEvents, int *numUserEvents
     return CPERFDMF_ERR_INTERNAL_ERROR;
   }
   
-  // grab each event
+  /* grab each event*/
   int i;
   for (i = 0; i < numEvents; i++) {
     getNextString(&events[i].name, buffer, userEventStr, &pos);
@@ -928,7 +928,7 @@ int cperfdmf_getUserEvents(cperfdmf_userEvent_t **userEvents, int *numUserEvents
 
   free (userEventStr);
 
-  // set the values to be returned
+  /* set the values to be returned*/
   *userEvents = events;
   *numUserEvents = numEvents;
   return CPERFDMF_OK;
