@@ -16,9 +16,9 @@
 #define JNI_VERSION_1_1 0x00010001
 #define JNI_VERSION_1_2 0x00010002
 
-// do some ifdef windows?
+/* do some ifdef windows?*/
 #define PATH_SEPARATOR ":"
-//#define USER_CLASSPATH ""
+/*#define USER_CLASSPATH ""*/
 
 
 #ifndef JAR_LOCATION
@@ -44,7 +44,7 @@ extern void cperfdmf_setExtendedError(char *template, ...);
 
 
 
-// this is here because strdup is not actually part of the C(99) library
+/* this is here because strdup is not actually part of the C(99) library*/
 static char* strduplicate (const char *source) {
   char* retStr = (char*) malloc (sizeof(char) * (strlen(source) + 1));
   if (!retStr)
@@ -80,7 +80,7 @@ static int getJavaException() {
   jstring msg;
   char* message;
   
-  //    (*env)->ExceptionDescribe(env);
+  /*    (*env)->ExceptionDescribe(env);*/
   if (0 != (except = (*env)->ExceptionOccurred(env))) {
     (*env)->ExceptionClear(env);
     
@@ -99,7 +99,7 @@ int jcperfdmf_init(char *configFile) {
   JavaVMInitArgs vm_args;
   jint res;
   char *classpath;
-  JavaVMOption options[2];
+  JavaVMOption options[3];
   FILE *file;
   char linebuf[2048];
   char *retVal;
@@ -114,7 +114,7 @@ int jcperfdmf_init(char *configFile) {
     if (strncmp(linebuf,"jdbc_db_jarfile:",16) == 0) {
       jdbcJarFile=&(linebuf[15]);
 
-      // null terminate it
+      /* null terminate it*/
       for (i=15;i<2048;i++) {
 	if (linebuf[i] == '\n' || linebuf[i] == '\r') {
 	  linebuf[i] = 0;
@@ -142,7 +142,9 @@ int jcperfdmf_init(char *configFile) {
   options[2].optionString = "-Xmx500m";
 
 
-  JNI_GetDefaultJavaVMInitArgs(&vm_args);
+/*     if (JNI_GetDefaultJavaVMInitArgs(&vm_args) < 0) { */
+/*       return CPERFDMF_ERR; */
+/*     } */
   
   /* IMPORTANT: specify vm_args version # if you use JDK1.1.2 and beyond */
   vm_args.version = JNI_VERSION_1_2;
@@ -150,6 +152,7 @@ int jcperfdmf_init(char *configFile) {
   vm_args.nOptions = 3;
   vm_args.ignoreUnrecognized = 1;
   
+
   /* Create the Java VM */
   res = JNI_CreateJavaVM(&jvm, (void**) &env, &vm_args);
   if (res < 0) {
@@ -185,7 +188,7 @@ int jcperfdmf_init(char *configFile) {
   integerHolderClass_get = (*env)->GetMethodID(env, integerHolderClass, "get", "()I");
   stringHolderClass_get = (*env)->GetMethodID(env, stringHolderClass, "get", "()Ljava/lang/String;");
 
-  // check those
+  /* check those*/
 
   return CPERFDMF_OK;
 };
